=========
kinet2pcb
=========


.. image:: https://img.shields.io/pypi/v/kinet2pcb.svg
        :target: https://pypi.python.org/pypi/kinet2pcb


Convert KiCad netlist into a PCBNEW ``.kicad_pcb`` file.


* Free software: MIT license
* Documentation: https://devbisme.github.io/kinet2pcb .


Features
--------

* Converts a KiCad netlist file into a ``.kicad_pcb`` file that can be edited with PCBNEW.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
